/**
 * Utils - Action
 */
import type { Actions } from './actionTypes.js';
/**
 * Add action to action object
 *
 * @param {string} name
 * @param {function} action
 * @return {boolean}
 */
declare const addAction: <T extends keyof Actions>(name: T, action: Actions[T]) => boolean;
/**
 * Remove action from actions object
 *
 * @param {string} name
 * @param {function} action
 * @return {boolean}
 */
declare const removeAction: <T extends keyof Actions>(name: T, action: Actions[T]) => boolean;
/**
 * Run callback functions from actions object
 *
 * @param {string} name
 * @param {*} [args]
 * @return {Promise<void>}
 */
declare const doActions: <T>(name: string, args?: T) => Promise<void>;
/**
 * Empty actions object
 *
 * @return {void}
 */
declare const resetActions: () => void;
/**
 * Fill actions object
 *
 * @param {Actions} args
 * @return {boolean}
 */
declare const setActions: (args: Partial<Actions>) => boolean;
export { addAction, removeAction, doActions, resetActions, setActions };
