"use strict";
/**
 * Utils - Content Type
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.getContentTypeLabels = exports.normalizeContentType = void 0;
const config_js_1 = require("../../config/config.js");
const object_js_1 = require("../object/object.js");
const string_js_1 = require("../string/string.js");
/**
 * Convert to normal content type if available
 *
 * @param {string} contentType
 * @return {string}
 */
const normalizeContentType = (contentType = '') => {
    if (!(0, string_js_1.isStringStrict)(contentType)) {
        return '';
    }
    const normalType = config_js_1.config.normalTypes[contentType];
    if ((0, string_js_1.isStringStrict)(normalType)) {
        return normalType;
    }
    return contentType;
};
exports.normalizeContentType = normalizeContentType;
/**
 * Singular and plural labels by content/taxonomy type
 *
 * @param {string} contentType
 * @param {string} [casing]
 * @param {Taxonomy} [taxonomy]
 * @return {ContentTypeLabels}
 */
const getContentTypeLabels = (contentType = '', casing = '', taxonomy) => {
    let singular = 'Post';
    let plural = 'Posts';
    let type = contentType;
    if ((0, object_js_1.isObjectStrict)(taxonomy)) {
        type = taxonomy.contentType;
    }
    if ((0, string_js_1.isStringStrict)(type)) {
        type = normalizeContentType(type);
        const s = config_js_1.config.archiveMeta[type]?.singular;
        const p = config_js_1.config.archiveMeta[type]?.plural;
        singular = (0, string_js_1.isStringStrict)(s) ? s : '';
        plural = (0, string_js_1.isStringStrict)(p) ? p : '';
    }
    if (casing === 'lower') {
        singular = singular.toLowerCase();
        plural = plural.toLowerCase();
    }
    if (casing === 'upper') {
        singular = singular.toUpperCase();
        plural = plural.toUpperCase();
    }
    return {
        singular,
        plural
    };
};
exports.getContentTypeLabels = getContentTypeLabels;
