"use strict";
/**
 * Utils - Path
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.getPathDepth = exports.getPath = void 0;
const config_js_1 = require("../../config/config.js");
const string_js_1 = require("../string/string.js");
/**
 * Get absolute path to file or file from config
 *
 * @param {string} file
 * @param {string} [type]
 * @return {string}
 */
const getPath = (file = '', type = '') => {
    const root = config_js_1.config.env.dir;
    if (!(0, string_js_1.isStringStrict)(root) || !(0, string_js_1.isStringStrict)(file)) {
        return '';
    }
    let append = file;
    if (type === 'store') {
        const dir = config_js_1.config.storeDir;
        const name = config_js_1.config.storeFiles[file]?.name;
        if ((0, string_js_1.isStringStrict)(dir) && (0, string_js_1.isStringStrict)(name)) {
            append = `${dir}/${name}`;
        }
    }
    if (file === 'image') {
        if (type === 'data') {
            const dataFile = config_js_1.config.image.dataFile;
            if ((0, string_js_1.isStringStrict)(dataFile)) {
                append = dataFile;
            }
        }
        if (type === 'input' || type === 'output') {
            const dirName = type === 'input' ? 'inputDir' : 'outputDir';
            const dir = config_js_1.config.image[dirName];
            if ((0, string_js_1.isStringStrict)(dir)) {
                append = `${dir}/${file}`;
            }
        }
    }
    if (type === 'serverless') {
        const dir = config_js_1.config.serverlessDir;
        const name = config_js_1.config.serverlessFiles[file];
        if ((0, string_js_1.isStringStrict)(dir) && (0, string_js_1.isStringStrict)(name)) {
            append = `${dir}/${name}`;
        }
    }
    return `${root}${root.endsWith('/') ? '' : '/'}${append}`;
};
exports.getPath = getPath;
/**
 * Relative ascendent path as string
 *
 * @param {string} path
 * @return {string}
 */
const getPathDepth = (path = '') => {
    let pathDepth = path.split('/');
    pathDepth.pop();
    pathDepth = pathDepth.map(() => {
        return '../';
    });
    return pathDepth.join('');
};
exports.getPathDepth = getPathDepth;
