"use strict";
/**
 * Utils - Print
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.print = void 0;
/* Imports */
const array_js_1 = require("../array/array.js");
const string_js_1 = require("../string/string.js");
/**
 * Output console message
 *
 * @param {string} pre
 * @param {string|string[]|*} message
 * @param {string} [type=error] - error | warning | success | info
 * @return {void}
 */
const print = (pre, message, type = 'error') => {
    const red = '\x1b[31m';
    const green = '\x1b[32m';
    const yellow = '\x1b[33m';
    const blue = '\x1b[36m';
    const reset = '\x1b[0m';
    const bold = '\x1b[1m';
    let msg = (0, array_js_1.isArray)(message) ? message : [message];
    if (msg.length > 0) {
        const lastIndex = msg.length - 1;
        msg = msg.map((m, i) => {
            if ((0, string_js_1.isString)(m) && i < lastIndex) {
                return `${m}\n`;
            }
            return m;
        });
    }
    if (type === 'error') {
        console.error(`${bold}${red}${pre}: ${reset}\n`, ...msg);
    }
    if (type === 'warning') {
        console.warn(`${bold}${yellow}${pre}: ${reset}\n`, ...msg);
    }
    if (type === 'success') {
        console.info(`${bold}${green}${pre}: ${reset}\n`, ...msg);
    }
    if (type === 'info') {
        console.info(`${bold}${blue}${pre}: ${reset}\n`, ...msg);
    }
};
exports.print = print;
