/**
 * Utils - Shortcode
 */
import type { Shortcode, Shortcodes } from './shortcodeTypes.js';
/**
 * Add shortcode to shortcodes object
 *
 * @param {string} name
 * @param {Shortcode} shortcode
 * @return {boolean}
 */
declare const addShortcode: <T extends Shortcode>(name: string, shortcode: T) => boolean;
/**
 * Remove shortcode from shortcodes object
 *
 * @param {string} name
 * @return {boolean}
 */
declare const removeShortcode: (name: string) => boolean;
/**
 * Transform content string with shortcode callbacks
 *
 * @param {string} content
 * @return {Promise<string>}
 */
declare const doShortcodes: (content: string) => Promise<string>;
/**
 * Empty shortcodes object
 *
 * @return {void}
 */
declare const resetShortcodes: () => void;
/**
 * Fill shortcodes object
 *
 * @param {Shortcodes} args
 * @return {boolean}
 */
declare const setShortcodes: <T extends Shortcodes>(args: T) => boolean;
/**
 * Remove shortcodes from string
 *
 * @param {string} content
 * @return {string}
 */
declare const stripShortcodes: (content: string) => string;
export { addShortcode, removeShortcode, doShortcodes, resetShortcodes, setShortcodes, stripShortcodes };
