/**
 * Utils - Content Type
 */
import { config } from '../../config/config.js';
import { isObjectStrict } from '../object/object.js';
import { isStringStrict } from '../string/string.js';
/**
 * Convert to normal content type if available
 *
 * @param {string} contentType
 * @return {string}
 */
const normalizeContentType = (contentType = '') => {
    if (!isStringStrict(contentType)) {
        return '';
    }
    const normalType = config.normalTypes[contentType];
    if (isStringStrict(normalType)) {
        return normalType;
    }
    return contentType;
};
/**
 * Singular and plural labels by content/taxonomy type
 *
 * @param {string} contentType
 * @param {string} [casing]
 * @param {Taxonomy} [taxonomy]
 * @return {ContentTypeLabels}
 */
const getContentTypeLabels = (contentType = '', casing = '', taxonomy) => {
    let singular = 'Post';
    let plural = 'Posts';
    let type = contentType;
    if (isObjectStrict(taxonomy)) {
        type = taxonomy.contentType;
    }
    if (isStringStrict(type)) {
        type = normalizeContentType(type);
        const s = config.archiveMeta[type]?.singular;
        const p = config.archiveMeta[type]?.plural;
        singular = isStringStrict(s) ? s : '';
        plural = isStringStrict(p) ? p : '';
    }
    if (casing === 'lower') {
        singular = singular.toLowerCase();
        plural = plural.toLowerCase();
    }
    if (casing === 'upper') {
        singular = singular.toUpperCase();
        plural = plural.toUpperCase();
    }
    return {
        singular,
        plural
    };
};
/* Exports */
export { normalizeContentType, getContentTypeLabels };
